@@ -1,10 +1,10 @@
 from . import (
+    logger,
     cfg,
     template,
     parameters,
     resolve,
     actions,
-    events,
     outputs,
     dashboard,
     ssm,
@@ -12,8 +12,7 @@ from . import (
 )
 from .aws import myboto3
 from .tools import smodule_to_class
-from .msg import init as msg_init
-from .common import *
+from .msg import msg
 
 
 class ibox_stack(object):
@@ -38,6 +37,13 @@ class ibox_stack(object):
         # i need to set attr to self.cfg and not to the common cfg
         self.cfg = smodule_to_class(cfg)
 
+        try:
+            # try to get already inited msg client
+            self.cfg.MSG = cfg.MSG
+        except Exception:
+            # or init it
+            self.cfg.MSG = msg()
+
     def create(self):
         self.exports = self.cfg.exports
         self.template = template.get_template(self)
@@ -62,7 +68,7 @@ class ibox_stack(object):
 
     def delete(self):
         self.stack = self.cloudformation.Stack(self.name)
-        result = actions.delete(self)
+        actions.delete(self)
 
     def cancel_update(self):
         self.stack = self.cloudformation.Stack(self.name)
@@ -112,7 +118,7 @@ class ibox_stack(object):
 
     def show_resources(self):
         self.stack = self.cloudformation.Stack(self.name)
-        result = actions.show_resources(self)
+        actions.show_resources(self)
 
     def log(self):
         self.stack = self.cloudformation.Stack(self.name)
@@ -148,17 +154,14 @@ class ibox_stack(object):
         except IOError:
             pass
         # logger.info(message)
-        client = msg_init(self)
-        if client and chat:
+
+        if chat:
             try:
-                client.chat_postMessage(
-                    channel=f"#{cfg.slack_channel}",
-                    text=message,
-                    username=self.cfg.MSG_USER,
-                    icon_emoji=":robot_face:",
-                )
+                self.cfg.MSG.send_smg(message)
             except Exception as e:
-                logger.warning(f"Error sending message to channel: {e}")
+                logger.warning(
+                    f"Error sending message to channel {self.cfg.MSG.msg_channel}: {e}"
+                )
 
     def dash(self):
         dashboard.add_stack(self)
@@ -174,6 +177,7 @@ class ibox_stack(object):
         self.template = template.get_template(self, stackset=True)
         self.stack = True
         parameters.process(self)
+        resolve.process(self)
         result = actions.stackset_update(self)
         if result:
             return {self.name: None}
@@ -194,12 +198,12 @@ class ibox_stack(object):
         parser.print_help()
 
     def stackset_show(self):
-        result = actions.stackset_show(self)
+        actions.stackset_show(self)
 
     def stackset_instances(self):
         cfg.fields = cfg.STACKSET_INSTANCES_SHOW_TABLE_FIELDS
         cfg.output = "text"
-        result = actions.stackset_instances(self)
+        actions.stackset_instances(self)
 
 
 def exec_command(name, data, command, region=None, **kwargs):
