@@ -574,6 +574,12 @@ def get_parser():
         help="Resolve Stack template - output in yaml short format",
     )
     parser_resolve.set_defaults(func=resolve)
+    parser_resolve.add_argument(
+        "-W",
+        "--write-path",
+        help="Write resolve yaml to write-path, "
+        "for directory filename is: {StackName}.yaml",
+    )
 
     # log parser
     parser_log = command_subparser.add_parser(
