@@ -1,7 +1,9 @@
 import botocore
 import yaml
+import os
 from pprint import pprint
 from collections import OrderedDict
+from pathlib import Path
 
 from . import logger, IboxError
 
@@ -313,14 +315,38 @@ def _do_check(istack):
 def show(istack):
     _process_template(istack)
     logger.info(f"Resolved: {istack.name}")
-    print(
-        yaml.dump(
-            {
-                "AWSTemplateFormatVersion": "2010-09-09",
-                "Resources": istack.r_resources,
-            }
-        )
-    )
+
+    stack_template = {
+        "AWSTemplateFormatVersion": "2010-09-09",
+        "Resources": istack.r_resources,
+    }
+
+    write_path = istack.cfg.write_path
+
+    if write_path:
+        write_path = os.path.abspath(write_path)
+
+        if os.path.splitext(write_path)[1]:
+            # path is a full file path
+            dirname = os.path.dirname(write_path)
+            out_file = write_path
+        else:
+            # path is a dir
+            dirname = write_path
+            out_file = os.path.join(dirname, f"{istack.name}.yaml")
+
+        # always create missing dir path
+        try:
+            Path(dirname).mkdir(parents=True, exist_ok=True)
+        except Exception as e:
+            logger.error(f"Error creating dir {dirname}: {e}")
+            exit(1)
+
+        with open(out_file, "w") as f:
+            yaml.dump(stack_template, f, Dumper=yaml.CDumper)
+            logger.info(f"Writed yaml: {out_file}")
+    else:
+        print(yaml.dump(stack_template))
 
 
 def process(istack):
