@@ -1,5 +1,6 @@
+from pprint import pprint
+
 from . import resources
-from .common import *
 
 
 def create(istack):
@@ -83,14 +84,18 @@ def create(istack):
                 if zone_region == istack.boto3.region_name:
                     return zoneid
 
-    istack.cfg.RESOURCES_MAP = istack.cfg.RESOURCES_MAP_R53
-    res = resources.get(istack)
+    res = resources.get(
+        istack, rtypes=["AWS::Route53::RecordSet", "AWS::ServiceDiscovery::Service"]
+    )
     pprint(res)
     out = {}
     for r, v in res.items():
         r_out = {}
         zoneid = None
-        if r.startswith("RecordSetExternal"):
+
+        # process Route53 RecordSet
+        if "External" in r:
+            # External
             record = _get_rec_info(v, "external")
             record_region = "%s.%s.%s" % (
                 record["role"],
@@ -103,27 +108,30 @@ def create(istack):
                 record_region: v,
             }
 
-            if "RecordSetCloudFront" not in res:
+            if all("RecordSetCloudFront" not in n for n in res) and not istack.cfg.safe:
                 map_record[record_cf] = record_region
 
-            if not istack.cfg.noorigin:
+            if not istack.cfg.noorigin and not istack.cfg.safe:
                 map_record[record_origin] = record_region
 
-        if r.startswith("RecordSetInternal"):
+        elif "Internal" in r:
+            # Internal
             record = _get_rec_info(v, "internal")
             record_internal = record["role"] + "." + record["domain"]
             map_record = {
                 record_internal: v,
             }
 
-        if r == "RecordSetCloudFront":
+        elif "CloudFront" in r and not istack.cfg.safe:
+            # CloudFront
             record = _get_rec_info(v, "cf")
             record_cf = record["role"] + "." + record["domain"]
             map_record = {
                 record_cf: v,
             }
 
-        if r.startswith("ServiceDiscoveryService"):
+        elif "ServiceDiscoveryService" in r:
+            # process ServiceDiscovery Service
             sd_record_name = _get_sd_info(v)
             record = _get_rec_info(sd_record_name, "sd")
             record_sd = record["role"] + "." + record["domain"]
@@ -132,6 +140,8 @@ def create(istack):
             }
             base_domain = ".".join(record["domain"].split(".")[1:])
             zoneid = _get_zoneid(base_domain)
+        else:
+            continue
 
         target_zoneid = _get_zoneid(record["domain"])
 
