@@ -1,4 +1,4 @@
-from .common import *
+from pprint import pformat
 
 
 def get_action_tags(istack, stack_tags):
@@ -12,6 +12,10 @@ def get_action_tags(istack, stack_tags):
 
     # changed tags - same value as corresponding stack param
     tags_changed = {}
+
+    # metadata tags - found inside template Metadata Section
+    tags_metadata = {}
+
     final_tags = []
 
     for tag in stack_tags:
@@ -55,11 +59,37 @@ def get_action_tags(istack, stack_tags):
 
         final_tags.append({"Key": key, "Value": value})
 
-    # Add cmd tags that do not have as Value REMOVE
-    for key, value in cmd_tags.items():
-        if value != "REMOVE":
-            final_tags.append({"Key": key, "Value": value})
-            tags_cmd[key] = value
+    final_tags_keys = [n["Key"] for n in final_tags]
+
+    upsert_tags_cfg = [
+        # Command line tags
+        (cmd_tags, tags_cmd),
+        # Metadata tags found inside template Metadata Section
+        (istack.metadata.get("Tags", {}), tags_metadata),
+    ]
+
+    # Add or Update Tags
+    for n in upsert_tags_cfg:
+        for key, value in n[0].items():
+            if key not in tags_remove:
+                # Tag must not be removed
+                tag = {"Key": key, "Value": value}
+                if tag in final_tags:
+                    # Tag already exist, skip it
+                    pass
+                elif key in final_tags_keys:
+                    # Tag Key already exist but with different Value, update it
+                    loc = final_tags_keys.index(key)
+                    tags_changed[key] = "%s => %s" % (
+                        final_tags[loc]["Value"],
+                        value,
+                    )
+                    final_tags[loc] = tag
+                    tags_default.pop(key, None)
+                else:
+                    # Tag Key do not exist, add/append it
+                    final_tags.append(tag)
+                    n[1][key] = value
 
     # Add LastUpdate Tag with current time
     # Currently disabled:
@@ -71,7 +101,7 @@ def get_action_tags(istack, stack_tags):
 
     if tags_default:
         istack.mylog(
-            "DEFAULT - STACK TAGS\n%s\n" % pformat(tags_default, width=1000000)
+            "CURRENT - STACK TAGS\n%s\n" % pformat(tags_default, width=1000000)
         )
     if tags_changed:
         istack.mylog(
@@ -81,6 +111,10 @@ def get_action_tags(istack, stack_tags):
         istack.mylog(
             "COMMAND LINE - STACK TAGS\n%s\n" % pformat(tags_cmd, width=1000000)
         )
+    if tags_metadata:
+        istack.mylog(
+            "METADATA - STACK TAGS\n%s\n" % pformat(tags_metadata, width=1000000)
+        )
     if tags_remove:
         istack.mylog("REMOVE - STACK TAGS\n%s\n" % pformat(tags_remove, width=1000000))
 
