@@ -1,16 +1,16 @@
 #!/usr/bin/env python3
 import sys
+
+from iboxstacksops import IboxError, logger, cfg
 from iboxstacksops.parser import set_cfg
-from iboxstacksops.common import IboxError, logger
-from iboxstacksops import cfg
-from iboxstacksops.msg import init as msg_init
+from iboxstacksops.msg import msg
 
 
 def main():
     set_cfg(sys.argv[1:])
 
     # Pre-Init msg client
-    msg_init()
+    cfg.MSG = msg()
 
     try:
         cfg.func()
